package CAIXS;
use parent 'Class::Accessor::Inherited::XS';
BEGIN {our $VERSION = $Class::Accessor::Inherited::XS::VERSION}
1;
__END__

=head1 NAME

CAIXS - L<Class::Accessor::Inherited::XS> shortcut for less typing

=head1 DESCRIPTION

See L<Class::Accessor::Inherited::XS> documentation for more details.
